@@ -9,6 +9,7 @@ function startFarabi(editorId) {
 	var $help_dialog = $("#help-dialog");
 	var $runDialog = $("#run-dialog");
 	var $openFileDialog    = $("#open-file-dialog");
+	var $actionsDialog    = $("#actions-dialog");
 	var $optionsDialog = $("#options-dialog");
 
 	$("#theme_selector").change(function() {
@@ -188,9 +189,34 @@ function startFarabi(editorId) {
 
 	$(".results").hide();
 
-	var $output = $("#output");
+	$("#action-name", $actionsDialog).typeahead({
+		source : function(query, process) {
+			$.ajax({
+				type: 'POST',
+				url: '/actions-typeahead',
+				async: false,
+				data: {'action-name': query},
+				success: function(matches) {
+					process(matches);
+				},
+				dataType: 'json',
+			});
+		}
+	})
+	
+	$("#ok-button", $actionsDialog).click(function() {
+		$actionsDialog.modal('hide');
+		var actionName = $("#action-name", $actionsDialog).val();
+		console.error(actionName);
+	});
 
-	$(".perl-tidy-button").click(function() {
+	$(".actions-button").click(function() {
+		$actionsDialog.modal('show');
+		$("#action-name").val('');
+		$("#action-name").focus();
+	});
+	
+	$(document).on('farabi-perl-tidy', function() {
 		$.post('/perl_tidy', {"source": editor.getValue()}, function(data) {
 			if(data.error == '') {
 				editor.setValue(data.source);
@@ -200,47 +226,43 @@ function startFarabi(editorId) {
 		});
 	});
 
-	$(".open-file-button").click(function() {
+	$(document).on('farabi-open-file', function() {
 		$openFileDialog.modal('show');
 		$("#file", $openFileDialog).val('').focus();
 		$("#search-results", $openFileDialog).empty();
 		$("#ok-button", $openFileDialog).attr("disabled","disabled");
 	});
 
-	$(".open-url-button").click(function() {
+	$(document).on('farabi-open-url', function() {
 		var url = prompt("Please Enter a http/https file location:" + 
 			"\ne.g https://raw.github.com/ihrd/uri/master/lib/URI.pm");
 		if(!url) {
+			alert("No URL was provided! Aborting");
 			return;
 		}
 		$.post('/open_url',
-        	{ "url": url },
-           	function(code) {
-            	editor.setValue(code);
-            }
-        );
+			{ "url": url },
+			function(code) {
+				editor.setValue(code);
+			}
+		);
 	});
 
-	$(".new-file-button").click(function() {
-		alert("TODO new file");
-	});
-
-	$(".syntax-check-button").click(function() {
+	$(document).on('farabi-syntax-check', function() {
 		alert("TODO syntax check");
 	});
 
-	$(".perl-critic-button").click(function() {
+	$(document).on('farabi-perl-critic', function() {
 		alert("TODO perl critic");
 	});
 
-	$(".options-button").click(function() {
+	$(document).on('farabi-options', function() {
 		$optionsDialog.modal('show');
 		$("#mode_selector", $optionsDialog).focus();
 	});
 
-
-	$(".run-button").click(function() {
-		
+	$(document).on('farabi-run', function() {
+		// Run file
 		$runDialog.modal('show');
 		$("#runtime", $runDialog).focus().change();
 	});
@@ -470,12 +492,11 @@ function startFarabi(editorId) {
 	var onCloseFocusEditor = function () {
 		editor.focus();
 	};
-	$perl_critic_dialog.hide().on('hidden', onCloseFocusEditor);
-	$about_dialog.hide().on('hidden', onCloseFocusEditor);
-	$help_dialog.hide().on('hidden', onCloseFocusEditor);
-	$runDialog.hide().on('hidden', onCloseFocusEditor);
-	$openFileDialog.hide().on('hidden', onCloseFocusEditor);
-	$optionsDialog.hide().on('hidden', onCloseFocusEditor);
+
+	// All modal dialogs are now hidden on startup
+	// And when hidden event is trigged, the focus is changed
+	// to the current editor
+	$(".modal").hide().on('hidden', onCloseFocusEditor);
 
 	$(".topic").typeahead({
 		source : function(query, process) {
